syntax

package
v0.9.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsWordChar

func IsWordChar(r rune) bool

IsWordChar reports whether r is considered a “word” character during the evaluation of the \b and \B zero-width assertions. These characters are [A-Za-z0-9_].

func Prefix

func Prefix(re *Regexp) (string, bool)

Prefix returns the constant prefix of the regular expression.

Types

type EmptyOp

type EmptyOp = gosyntax.EmptyOp

EmptyOp is a bitmask of empty-width assertions.

const (
	EmptyBeginLine      EmptyOp = gosyntax.EmptyBeginLine
	EmptyEndLine        EmptyOp = gosyntax.EmptyEndLine
	EmptyBeginText      EmptyOp = gosyntax.EmptyBeginText
	EmptyEndText        EmptyOp = gosyntax.EmptyEndText
	EmptyWordBoundary   EmptyOp = gosyntax.EmptyWordBoundary
	EmptyNoWordBoundary EmptyOp = gosyntax.EmptyNoWordBoundary
)

func EmptyOpContext

func EmptyOpContext(r1, r2 rune) EmptyOp

EmptyOpContext returns the EmptyOp at the position between r1 and r2.

type Error

type Error = gosyntax.Error

An Error describes a failure to parse a regular expression and gives the offending expression.

type ErrorCode

type ErrorCode = gosyntax.ErrorCode

An ErrorCode describes a category of parsing error.

const (
	ErrInternalError ErrorCode = gosyntax.ErrInternalError

	// Parse errors
	ErrInvalidRepeatOp       ErrorCode = gosyntax.ErrInvalidRepeatOp
	ErrInvalidRepeatSize     ErrorCode = gosyntax.ErrInvalidRepeatSize
	ErrInvalidEscape         ErrorCode = gosyntax.ErrInvalidEscape
	ErrInvalidNamedCapture   ErrorCode = gosyntax.ErrInvalidNamedCapture
	ErrInvalidCharClass      ErrorCode = gosyntax.ErrInvalidCharClass
	ErrInvalidCharRange      ErrorCode = gosyntax.ErrInvalidCharRange
	ErrMissingBracket        ErrorCode = gosyntax.ErrMissingBracket
	ErrMissingParen          ErrorCode = gosyntax.ErrMissingParen
	ErrMissingRepeatArgument ErrorCode = gosyntax.ErrMissingRepeatArgument
	ErrTrailingBackslash     ErrorCode = gosyntax.ErrTrailingBackslash
	ErrUnexpectedParen       ErrorCode = gosyntax.ErrUnexpectedParen
)

type Flags

type Flags = gosyntax.Flags
const (
	FoldCase      Flags = gosyntax.FoldCase
	Literal       Flags = gosyntax.Literal
	ClassNL       Flags = gosyntax.ClassNL
	DotNL         Flags = gosyntax.DotNL
	OneLine       Flags = gosyntax.OneLine
	NonGreedy     Flags = gosyntax.NonGreedy
	PerlX         Flags = gosyntax.PerlX
	UnicodeGroups Flags = gosyntax.UnicodeGroups
	WasDollar     Flags = gosyntax.WasDollar
	Simple        Flags = gosyntax.Simple

	MatchNL = gosyntax.MatchNL

	Perl  = gosyntax.Perl
	POSIX = gosyntax.POSIX
)

type Inst

type Inst = gosyntax.Inst

Inst is a single instruction in a regular expression program.

type InstOp

type InstOp = gosyntax.InstOp

InstOp is an instruction opcode.

const (
	InstAlt          InstOp = gosyntax.InstAlt
	InstAltMatch     InstOp = gosyntax.InstAltMatch
	InstCapture      InstOp = gosyntax.InstCapture
	InstEmptyWidth   InstOp = gosyntax.InstEmptyWidth
	InstMatch        InstOp = gosyntax.InstMatch
	InstFail         InstOp = gosyntax.InstFail
	InstNop          InstOp = gosyntax.InstNop
	InstRune         InstOp = gosyntax.InstRune
	InstRune1        InstOp = gosyntax.InstRune1
	InstRuneAny      InstOp = gosyntax.InstRuneAny
	InstRuneAnyNotNL InstOp = gosyntax.InstRuneAnyNotNL
)

type Op

type Op = gosyntax.Op

Op is a regular expression operator.

const (
	OpNoMatch        Op = gosyntax.OpNoMatch
	OpEmptyMatch     Op = gosyntax.OpEmptyMatch
	OpLiteral        Op = gosyntax.OpLiteral
	OpCharClass      Op = gosyntax.OpCharClass
	OpAnyCharNotNL   Op = gosyntax.OpAnyCharNotNL
	OpAnyChar        Op = gosyntax.OpAnyChar
	OpBeginLine      Op = gosyntax.OpBeginLine
	OpEndLine        Op = gosyntax.OpEndLine
	OpBeginText      Op = gosyntax.OpBeginText
	OpEndText        Op = gosyntax.OpEndText
	OpWordBoundary   Op = gosyntax.OpWordBoundary
	OpNoWordBoundary Op = gosyntax.OpNoWordBoundary
	OpCapture        Op = gosyntax.OpCapture
	OpStar           Op = gosyntax.OpStar
	OpPlus           Op = gosyntax.OpPlus
	OpQuest          Op = gosyntax.OpQuest
	OpRepeat         Op = gosyntax.OpRepeat
	OpConcat         Op = gosyntax.OpConcat
	OpAlternate      Op = gosyntax.OpAlternate
)

type Prog

type Prog = gosyntax.Prog

Prog is a compiled regular expression program.

func Compile

func Compile(re *Regexp) (*Prog, error)

Compile compiles the regular expression to a program.

type Regexp

type Regexp = gosyntax.Regexp

func Optimize

func Optimize(re *Regexp) *Regexp

Optimize returns an optimized version of the regular expression. It merges common prefixes in alternations to reduce the number of DFA states.

func Parse

func Parse(s string, flags Flags) (*Regexp, error)

func ParsePOSIX

func ParsePOSIX(s string, flags Flags) (*Regexp, error)

func Simplify

func Simplify(re *Regexp) *Regexp

Simplify returns a simplified version of the regular expression.

type UnsupportedError

type UnsupportedError struct {
	Op string
}

func (*UnsupportedError) Error

func (e *UnsupportedError) Error() string

Jump to